@@ -38,7 +38,8 @@ def _remove_prefix(path):
 def _download_file(url,
                    skip_if_exists=False,
                    raise_on_missing=False,
-                   path=None):
+                   path=None,
+                   summary=False):
     try:
         response = _requests.get(url)
 
@@ -75,7 +76,10 @@ def _download_file(url,
         print(f'{path} exists, skipping...')
     else:
         Path(path).parent.mkdir(exist_ok=True, parents=True)
-        print(f'Writing file into path {path}')
+
+        if not summary:
+            print(f'Writing file to: {path}')
+
         try:
             with open(path, "wb") as file:
                 file.write(response.content)
@@ -85,15 +89,17 @@ def _download_file(url,
     return path
 
 
-def download_from_presigned(presigned):
+def download_from_presigned(presigned, summary):
     if not presigned:
         click.echo('No files matched the criteria.\n'
                    'To list files: ploomber cloud products')
         return
 
+    downloaded = 0
+
     with ThreadPoolExecutor(max_workers=64) as executor:
         future2url = {
-            executor.submit(_download_file, url=url): url
+            executor.submit(_download_file, url=url, summary=summary): url
             for url in presigned
         }
 
@@ -105,6 +111,11 @@ def download_from_presigned(presigned):
                 raise RuntimeError(
                     'An error occurred when downloading product from '
                     f'url: {task!r}') from exception
+            else:
+                downloaded += 1
+
+    if summary:
+        click.echo(f'Downloaded {downloaded} files.')
 
 
 def _parse_datetime(timestamp):
@@ -308,11 +319,11 @@ class PloomberCloudAPI:
             print("No data found.")
 
     @auth_header
-    def products_download(self, headers, pattern):
+    def products_download(self, headers, pattern, summary):
         res = _requests.post(f"{self._host}/products",
                              headers=headers,
                              json=dict(pattern=pattern)).json()
-        download_from_presigned(res)
+        download_from_presigned(res, summary=summary)
 
     @auth_header
     def get_presigned_link(self, headers, runid):
@@ -402,7 +413,14 @@ class PloomberCloudAPI:
         response = _requests.delete(f"{self._host}/products",
                                     headers=headers,
                                     json=dict(pattern=pattern))
-        print(response.json())
+
+        deleted = response.json()
+
+        if deleted:
+            click.echo('Deleted:')
+            click.echo('\n'.join(f'* {path}' for path in deleted))
+        else:
+            click.echo('Nothing to delete: no files matched the criteria.')
 
     @auth_header
     def notebooks_interface(self, headers, nbid):
@@ -430,7 +448,7 @@ class PloomberCloudAPI:
             run_id = self.run_latest_id()
         return run_id
 
-    def run_detail_print(self, run_id, json=False):
+    def run_detail_print(self, run_id, json=False, summary=False):
         run_id = self.process_run_id(run_id)
         out = self.run_detail(run_id)
         tasks = out['tasks']
@@ -442,7 +460,9 @@ class PloomberCloudAPI:
 
         elif run['status'] == 'finished':
             if tasks:
-                formatter(tasks, json_=json)
+                formatter(
+                    tasks if not summary else summarize_tasks_status(tasks),
+                    json_=json)
             else:
                 echo('Pipeline finished due to no newly triggered tasks,'
                      ' try running ploomber cloud build --force')
@@ -459,7 +479,8 @@ class PloomberCloudAPI:
             elif run['status'] == 'aborted':
                 echo('Pipeline aborted...')
 
-            formatter(tasks, json_=json)
+            formatter(tasks if not summary else summarize_tasks_status(tasks),
+                      json_=json)
 
             if run['status'] == 'failed':
                 echo(
@@ -614,3 +635,14 @@ def upload_zipped_project(response, verbose, *, base_dir):
 
     if verbose:
         click.echo("Uploaded project, starting execution...")
+
+
+def summarize_tasks_status(tasks):
+    status = [task['status'] for task in tasks]
+
+    summary = [{
+        'status': value,
+        'count': status.count(value)
+    } for value in set(status)]
+
+    return summary
