@@ -711,11 +711,19 @@ class DAG(AbstractDAG):
                                '"%s", skipping', self.name)
 
     def _deepcopy_safe(self):
+        clients = self.clients
+        self._clients = None
+
         try:
-            return deepcopy(self)
+            copy = deepcopy(self)
         except Exception as e:
             raise RuntimeError(
                 "An error occurred while copying DAG object") from e
+        finally:
+            self._clients = clients
+
+        copy._clients = clients
+        return copy
 
     def build_partially(self,
                         target,
@@ -762,11 +770,26 @@ class DAG(AbstractDAG):
             .. versionadded:: 0.20
                 ``debug`` now supports debugging NotebookRunner tasks
         """
+        return self._build_partially(target=target,
+                                     force=force,
+                                     show_progress=show_progress,
+                                     debug=debug,
+                                     skip_upstream=skip_upstream,
+                                     deepcopy=True)
 
+    def _build_partially(self,
+                         target,
+                         force=False,
+                         show_progress=True,
+                         debug=None,
+                         skip_upstream=False,
+                         deepcopy=True):
         # we have to use a deep copy since using a soft one will corrupt
         # task status in subsequent runs
-
-        dag_copy = self._deepcopy_safe()
+        if deepcopy:
+            dag_another = self._deepcopy_safe()
+        else:
+            dag_another = self
 
         # task names are usually str, although this isn't strictly enforced
         if isinstance(target, str) and '*' in target:
@@ -786,28 +809,28 @@ class DAG(AbstractDAG):
             targets = {target}
             lineage = self[target]._lineage or set()
 
-        to_remove = set(dag_copy) - targets - lineage
+        to_remove = set(dag_another) - targets - lineage
 
         for task in to_remove:
-            dag_copy.pop(task)
+            dag_another.pop(task)
 
         # clear metadata in the original dag, because building the copy
         # will make it outdated, we have to force reload from disk
         self._clear_metadata()
 
         if skip_upstream:
-            dag_copy.render(force=force, show_progress=show_progress)
-            # to prevent call to dag_copy.render() inside dag_copy.build()
+            dag_another.render(force=force, show_progress=show_progress)
+            # to prevent call to self.render() inside self.build()
             # to overwrite Skipped status
-            dag_copy._params.cache_rendered_status = True
+            dag_another._params.cache_rendered_status = True
 
-            for name, task in dag_copy.items():
+            for name, task in dag_another.items():
                 if name not in targets:
-                    dag_copy[name].exec_status = TaskStatus.Skipped
+                    dag_another[name].exec_status = TaskStatus.Skipped
 
-        return dag_copy.build(force=force,
-                              show_progress=show_progress,
-                              debug=debug)
+        return dag_another.build(force=force,
+                                 show_progress=show_progress,
+                                 debug=debug)
 
     def status(self, **kwargs):
         """Returns a table with tasks status
