@@ -1,3 +1,4 @@
+import ast
 import re
 import warnings
 from io import StringIO
@@ -64,6 +65,7 @@ def process_errors_and_warnings(messages):
 
 # https://github.com/PyCQA/pyflakes/blob/master/pyflakes/reporter.py
 class MyReporter(Reporter):
+
     def __init__(self):
         self._stdout = StringIO()
         self._stderr = StringIO()
@@ -278,6 +280,33 @@ def _is_ipython_cell_magic(source):
     return m.group()
 
 
+class ParamsCell:
+    """Parse variables defined in a  notebook cell
+    """
+
+    def __init__(self, source):
+        self._source = source
+        # dot not complain if product or upstream are missing since
+        # they are not user-defined params
+        self._IGNORE = {'product', 'upstream'}
+
+        self._declared = _get_defined_variables(self._source)
+
+        for key in self._IGNORE:
+            self._declared.pop(key, None)
+
+    def get_defined(self):
+        return self._declared
+
+    def get_missing(self, passed):
+        passed = set(passed) - self._IGNORE
+        return set(self._declared) - passed
+
+    def get_unexpected(self, passed):
+        passed = set(passed) - self._IGNORE
+        return passed - set(self._declared)
+
+
 def check_params(passed, params_source, filename, warn=False):
     """
     Check that parameters passed to the notebook match the ones defined
@@ -304,14 +333,9 @@ def check_params(passed, params_source, filename, warn=False):
         If passed parameters do not match variables declared in params_source
         and warn is False
     """
-    # dot not complain if product or upstream are missing since
-    # they are not user-defined params
-    IGNORE = {'product', 'upstream'}
-
-    declared = _get_defined_variables(params_source) - IGNORE
-    passed = set(passed) - IGNORE
-    missing = declared - passed
-    unexpected = passed - declared
+    params_cell = ParamsCell(params_source)
+    missing = params_cell.get_missing(passed)
+    unexpected = params_cell.get_unexpected(passed)
 
     if missing or unexpected:
         errors = []
@@ -350,6 +374,19 @@ def _get_defined_variables(params_source):
     variable assignments (e.g., function definitions, exceptions)
     """
     used_names = parso.parse(params_source).get_used_names()
-    return set(key for key, value in used_names.items()
-               if value[-1].is_definition()
-               and value[-1].get_definition().type == 'expr_stmt')
+
+    def _get_value(value):
+        possible_literal = value.get_definition().children[-1].get_code(
+        ).strip()
+
+        try:
+            # NOTE: this cannot parse dict(a=1, b=2)
+            return ast.literal_eval(possible_literal)
+        except ValueError:
+            return None
+
+    return {
+        key: _get_value(value[-1])
+        for key, value in used_names.items() if value[-1].is_definition()
+        and value[-1].get_definition().type == 'expr_stmt'
+    }
