@@ -502,6 +502,8 @@ def cloud_build(force, json):
     $ ploomber cloud build --force
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
+
     api = PloomberCloudAPI()
     runid = api.build(force,
                       github_number=None,
@@ -512,6 +514,9 @@ def cloud_build(force, json):
     if json:
         click.echo(json_module.dumps(dict(runid=runid)))
 
+    telemetry.log_api("cloud-build",
+                      metadata={'force': force, 'json': json})
+
 
 @cloud.command(name='task')
 @click.argument('task_name')
@@ -530,6 +535,8 @@ def cloud_task(task_name, force, json):
     $ ploomber cloud task {task-name} --force
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
+
     api = PloomberCloudAPI()
     runid = api.build(force,
                       github_number=None,
@@ -540,6 +547,13 @@ def cloud_task(task_name, force, json):
     if json:
         click.echo(json_module.dumps(dict(runid=runid)))
 
+    telemetry.log_api("cloud-task",
+                      metadata={
+                          'task_name': task_name,
+                          'force': force,
+                          'json': json
+                      })
+
 
 @cloud.command(name="list")
 @click.option('--json', is_flag=True)
@@ -549,15 +563,22 @@ def cloud_list(json):
     $ ploomber cloud list
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
     api = PloomberCloudAPI()
     api.runs(json=json)
 
+    telemetry.log_api("cloud-list",
+                      metadata={
+                          'json': json
+                      })
+
 
 @cloud.command(name="status")
 @click.argument('run_id')
 @click.option('--watch', '-w', is_flag=True)
 @click.option('--json', is_flag=True)
-def cloud_status(run_id, watch, json):
+@click.option('--summary', '-s', is_flag=True)
+def cloud_status(run_id, watch, json, summary):
     """Get task's execution status:
 
     $ ploomber cloud status {some-id}
@@ -565,8 +586,14 @@ def cloud_status(run_id, watch, json):
     Get task's status of latest execution:
 
     $ ploomber cloud status @latest
+
+    Only print the status count:
+
+    $ ploomber cloud status @latest --summary
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
+
     api = PloomberCloudAPI()
 
     if watch:
@@ -576,7 +603,7 @@ def cloud_status(run_id, watch, json):
 
         while cumsum < timeout:
             click.clear()
-            out = api.run_detail_print(run_id)
+            out = api.run_detail_print(run_id, summary=summary)
 
             status = set([t['status'] for t in out['tasks']])
 
@@ -588,7 +615,15 @@ def cloud_status(run_id, watch, json):
             time.sleep(idle)
             cumsum += idle
     else:
-        api.run_detail_print(run_id, json=json)
+        api.run_detail_print(run_id, json=json, summary=summary)
+
+    telemetry.log_api("cloud-status",
+                      metadata={
+                          'run_id': run_id,
+                          'watch': watch,
+                          'json': json,
+                          'summary': summary
+                      })
 
 
 @cloud.command(name="products")
@@ -610,6 +645,8 @@ def cloud_products(delete, json):
     $ ploomber cloud products --delete '*.csv'
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
+
     api = PloomberCloudAPI()
 
     if delete:
@@ -617,10 +654,17 @@ def cloud_products(delete, json):
     else:
         api.products_list(json=json)
 
+    telemetry.log_api("cloud-products",
+                      metadata={
+                          'delete': delete,
+                          'json': json
+                      })
+
 
 @cloud.command(name="download")
 @click.argument('pattern')
-def cloud_download(pattern):
+@click.option('--summary', '-s', is_flag=True)
+def cloud_download(pattern, summary):
     """Download products from cloud workspace:
 
     $ ploomber cloud download {pattern}
@@ -628,10 +672,21 @@ def cloud_download(pattern):
     Download all .csv files:
 
     $ ploomber cloud download '*.csv'
+
+    Only print the number of downloaded files:
+
+    $ ploomber cloud download '*.csv' --summary
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
     api = PloomberCloudAPI()
-    api.products_download(pattern)
+    api.products_download(pattern, summary=summary)
+
+    telemetry.log_api("cloud-download",
+                      metadata={
+                          'pattern': pattern,
+                          'summary': summary
+                      })
 
 
 @cloud.command(name="logs")
@@ -663,6 +718,8 @@ def cloud_logs(run_id, image, watch, task):
     $ ploomber cloud logs @latest --watch
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
+
     api = PloomberCloudAPI()
 
     if image:
@@ -684,6 +741,14 @@ def cloud_logs(run_id, image, watch, task):
     else:
         api.run_logs(run_id, task)
 
+    telemetry.log_api("cloud-logs",
+                      metadata={
+                          'run_id': run_id,
+                          'image': image,
+                          'watch': watch,
+                          'task': task
+                      })
+
 
 @cloud.command(name="abort")
 @click.argument('run_id')
@@ -697,9 +762,15 @@ def cloud_abort(run_id):
     $ ploomber cloud abort @latest
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
     api = PloomberCloudAPI()
     api.run_abort(run_id)
 
+    telemetry.log_api("cloud-abort",
+                      metadata={
+                          'run_id': run_id
+                      })
+
 
 @cloud.command(name="data")
 @click.option('-u', '--upload', default=None)
@@ -736,6 +807,7 @@ def cloud_data(upload, delete, prefix, name):
     >>> download_data('dataset.parquet') # doctest: +SKIP
     """
     from ploomber.cloud.api import PloomberCloudAPI
+    from ploomber.telemetry import telemetry
     api = PloomberCloudAPI()
 
     # one arg max
@@ -761,6 +833,14 @@ def cloud_data(upload, delete, prefix, name):
 
         api.data_list()
 
+    telemetry.log_api("cloud-data",
+                      metadata={
+                          'upload': upload,
+                          'delete': delete,
+                          'prefix': prefix,
+                          'name': name
+                      })
+
 
 @cloud.command(name="nb")
 @click.argument('path_to_notebook')
@@ -772,6 +852,7 @@ def cloud_notebook(path_to_notebook, json):
     """
     from ploomber.cloud.api import PloomberCloudAPI
     from ploomber.cloud import io
+    from ploomber.telemetry import telemetry
 
     # TODO: add unit test
     path_to_notebook = io.download_notebook_if_needed(path_to_notebook)
@@ -805,3 +886,9 @@ def cloud_notebook(path_to_notebook, json):
             "Done. Monitor Docker build process with:\n  "
             f"$ ploomber cloud logs {runid} --image --watch",
             fg='green')
+
+    telemetry.log_api("cloud-nb",
+                      metadata={
+                          'path_to_notebook': path_to_notebook,
+                          'json': json
+                      })
